import React from 'react';
import { MapPin, ChevronRight, ChevronLeft, CheckCircle } from 'lucide-react';

const CitiesSection = () => {
  const cities = [{
    name: "Lisbon",
    region: "Europe",
    image: "https://images.unsplash.com/photo-1580323956656-26bbb1206e34?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=1935&q=80"
  }, {
    name: "Split",
    region: "Europe",
    image: "https://images.unsplash.com/photo-1555990538-17835ba5a1c3?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=1934&q=80"
  }, {
    name: "Mexico City",
    region: "North America",
    image: "https://images.unsplash.com/photo-1518659526054-190340b35735?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=1974&q=80"
  }, {
    name: "Bali",
    region: "Asia",
    image: "https://images.unsplash.com/photo-1537996194471-e657df975ab4?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=1938&q=80"
  }, {
    name: "Chiang Mai",
    region: "Asia",
    image: "https://images.unsplash.com/photo-1598997444018-b37bb0175d94?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=1974&q=80"
  }, {
    name: "Medellín",
    region: "South America",
    image: "https://images.unsplash.com/photo-1619218005459-c8649bc9d8a1?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=1742&q=80"
  }];
  const allCities = ["Lisbon", "Split", "Crete", "Gran Canaria", "Tirana", "Marrakech", "Dubai", "Florianópolis", "Búzios", "Medellín", "Mexico City", "Tulum", "Puerto Escondido", "Miami", "Bangkok", "Chiang Mai", "Phuket", "Koh Samui", "Bali"];

  const scrollContainer = (direction: 'left' | 'right') => {
    const container = document.getElementById('cities-container');
    if (container) {
      const scrollAmount = direction === 'left' ? -300 : 300;
      container.scrollBy({
        left: scrollAmount,
        behavior: 'smooth'
      });
    }
  };
  
  return (
    <section id="cities" className="section bg-nomad-slate text-white relative overflow-hidden">
      <div className="absolute top-0 right-0 w-1/2 h-full bg-nomad-green/10 blur-3xl rounded-full transform translate-x-1/2"></div>
      
      <div className="container relative z-10">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center mb-16">
          <div>
            <img 
              src="https://images.unsplash.com/photo-1522202176988-66273c2fd55f?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=2071&q=80" 
              alt="Digital nomad working" 
              className="rounded-xl shadow-lg"
            />
          </div>
          
          <div>
            <h2 className="text-3xl md:text-4xl font-bold mb-6 text-nomad-terracotta">This is not a generic travel guide</h2>
            
            <p className="text-xl mb-8">
              It's an experience-based resource created after three years of living and working in over 30 nomad-friendly cities, while running a six-figure design business.
            </p>
            
            <div className="flex items-start gap-4 mb-8">
              <div className="bg-nomad-terracotta/20 p-2 rounded-full mt-1">
                <CheckCircle className="w-6 h-6 text-nomad-terracotta" />
              </div>
              <div>
                <h3 className="text-xl font-semibold mb-1">No fluff. No recycled blogs. No generic AI advice.</h3>
                <p className="text-white/80">Only real insights from a working designer who's lived the nomad experience.</p>
              </div>
            </div>
            
            <div className="bg-nomad-slate/50 p-5 rounded-xl border border-white/10 backdrop-blur-sm">
              <div className="flex items-center gap-2 mb-3">
                <MapPin className="text-nomad-terracotta" />
                <h4 className="font-medium">Currently in Mexico City</h4>
              </div>
              
              <p className="text-white/80 mb-4">With upcoming travels to:</p>
              
              <div className="flex flex-wrap gap-2">
                {['Buenos Aires', 'Barcelona', 'Istanbul', 'Sri Lanka', 'Cape Town', 'Sydney'].map((city, index) => (
                  <div key={index} className="bg-white/10 py-1 px-3 rounded-full text-sm">
                    {city}
                  </div>
                ))}
              </div>
            </div>
          </div>
        </div>

        <div className="relative">
          <button onClick={() => scrollContainer('left')} className="absolute left-0 top-1/2 transform -translate-y-1/2 z-20 bg-white/20 hover:bg-white/30 rounded-full p-2 backdrop-blur-sm" aria-label="Scroll left">
            <ChevronLeft className="w-6 h-6" />
          </button>
          
          <button onClick={() => scrollContainer('right')} className="absolute right-0 top-1/2 transform -translate-y-1/2 z-20 bg-white/20 hover:bg-white/30 rounded-full p-2 backdrop-blur-sm" aria-label="Scroll right">
            <ChevronRight className="w-6 h-6" />
          </button>
        </div>
      </div>
    </section>
  );
};

export default CitiesSection;
